/*
Pierre Hébert - Sketch - 2014
This software is provided as is. Public domain.
You are free to use, duplicate and modify it without restriction.
*/
var MY_PKG = "net.pierrox.lightning_launcher.llscript.sketch";


// install (or update) a script given its id in the package, and its clear name in the launcher data
function installScript(id, name) {
    // load the script (if any) among the existing ones
    var script = LL.getScriptByName(name);

    // load the touch handler from the package
    var script_text = LL.loadRawResource(MY_PKG, id);

    if(script == null) {
        // script not found: install it
        script = LL.createScript(name, script_text , 0);
    } else {
        // the script already exists: update its text
        script.setText(script_text);
    }

    return script;
}

var script_touch = installScript("sketch_touch", "Sketch / touch handler");
var script_btn = installScript("sketch_btn", "Sketch / button handler");


// create the sketchpad item (a container panel, a dummy shortcut for the drawing and a few shortcuts for actions) after asking the user for its size
var w = prompt("Sketchpad width: how many columns would you like the sketchpad to be wide ?", 3);
var h = prompt("Sketchpad height ?", 3);

var d = LL.getCurrentDesktop();

// panel grid columns and rows, changing these values affect the layout of the buttons and the drawing itself
var panel_grid_c = 5;
var panel_grid_r = 6;

// create a panel, which will contain the drawing and some buttons, configure its internal size to 4x4, and set a black border around
var panel = d.addPanel(0, 0, w*d.getCellWidth(), h*d.getCellHeight());
var ed = panel.getProperties().edit();
var box = ed.getBox("i.box");
box.setColor("bl,br,bt,bb", "ns", 0xff000000);
box.setSize("bl,br,bt,bb", 4);
box.setSize("ml,mr,mt,mb", 4);
ed.commit();
var panel_container = panel.getContainer();
panel_container.getProperties().edit().setInteger("gridPColumnNum", panel_grid_c).setInteger("gridPRowNum", panel_grid_r).commit();

// add and configure the drawing item (no icon, label on top, event handler...)
var drawing = panel_container.addShortcut("drawing", new Intent(), 0, 0);
drawing.setCell(0, 1, panel_grid_c, panel_grid_r, true);
var ed = drawing.getProperties().edit();
ed.setBoolean("s.iconVisibility", false);
ed.setBoolean("s.labelVisibility", false);
ed.getBox("i.box").setAlignment("CENTER", "TOP");
ed.setEventHandler("i.touch", EventHandler.RUN_SCRIPT, script_touch.getId());
ed.commit();

// set a blank white image as the sketchpad background
var bg = LL.createImage(512, 512);
bg.draw().drawARGB(255, 255, 255, 255);
drawing.setBoxBackground(bg, "n");
drawing.getBoxBackground("n").save();

// create some buttons (colors, clear)
var btn_delete = panel_container.addShortcut("clear", new Intent(), 0, 0);
btn_delete.setCell(panel_grid_c-1, 0, panel_grid_c, 1, true);
btn_delete.getProperties().edit().setBoolean("s.labelVisibility", false).setBoolean("s.iconReflection", false).setEventHandler("i.tap", EventHandler.RUN_SCRIPT, script_btn.getId()).commit();
btn_delete.setDefaultIcon(LL.createImage(MY_PKG, "ic_menu_delete"));

var colors = [ 0xff000000, 0xff00ff00, 0xffff0000, 0xff0000ff];
for(var i=0; i<colors.length; i++) {
    var btn = panel_container.addShortcut("color", new Intent(), 0, 0);
    btn.setCell(i, 0, i+1, 1, true);
    ed = btn.getProperties().edit();
    ed.setBoolean("s.labelVisibility", false).setBoolean("s.iconVisibility", false);
    ed.setEventHandler("i.tap", EventHandler.RUN_SCRIPT, script_btn.getId())
    box = ed.getBox("i.box");
    box.setColor("c", "ns", colors[i]);
    box.setSize("ml,mr,mt,mb", 8);
    ed.commit();
}